Common types used by other Holochain crates.
This crate is a complement to the holochain_zome_types crate, which contains only the essential types which are used in Holochain DNA code. This crate expands on those types to include all types which Holochain itself depends on.
Modules
- access
- Defines HostFnAccess and Permission
- activity
- Types for agents chain activity
- app
- Everything to do with App (hApp) installation and uninstallation
- cell_
config_ overrides - Cell configuration overrides module.
- chain
- Types related to an agents for chain activity
- combinators
- Combinator functions, for more easeful functional programming
- countersigning
- Types related to countersigning sessions.
- dna
- dna is a library for working with holochain dna files/entries.
- entry
- An Entry is a unit of data in a Holochain Source Chain.
- error
- Error types for DHT op rendering and construction.
- link
- Links interrelate entries in a source chain.
- network
- Types for interacting with Holochain’s network layer.
- op
- DHT state-model op types (see
docs/design/state_model.md). - prelude
- reexport some common things
- record
- Defines a Record, the basic unit of Holochain data.
- report
- Types associated with holochain reporting.
- share
- A sync RwLock that uses closures to avoid deadlocks.
- signal
- Signals which can be emitted from within Holochain, out across an interface. There are two main kinds of Signal: system-defined, and app-defined:
- validation_
receipt - Types for validation receipts and signed validation receipts to be sent between peers.
- warrant
- Defines the Warrant variant of DhtOp
- web_app
- Web App manifest describing how to bind a Web UI and a happ bundle together
- websocket
- Common types for WebSocket connections.
- wire_
ops - Wire representations of DHT ops served in response to GET requests, and the rendered form they expand into for caching.
- zome_
types - Helpers for constructing and using zome types correctly.
Macros
- impl_
from - Utility for removing boilerplate from From impls