SessionResolutionSummary

Struct SessionResolutionSummary 

pub struct SessionResolutionSummary {
    pub required_reason: ResolutionRequiredReason,
    pub attempts: usize,
    pub last_attempt_at: Option<Timestamp>,
    pub outcomes: Vec<SessionResolutionOutcome>,
}
Summary of the workflow’s attempts to resolve the outcome a failed countersigning session.

This tracks the numbers of attempts and the outcome of the most recent attempt.

Fields

required_reason: ResolutionRequiredReason

The reason why session resolution is required.

attempts: usize

How many attempts have been made to resolve the session.

This count is only correct for the current run of the Holochain conductor. If the conductor is restarted then this counter is also reset.

last_attempt_at: Option<Timestamp>

The time of the last attempt to resolve the session.

outcomes: Vec<SessionResolutionOutcome>

The outcome of the most recent attempt to resolve the session.