Module sql

Module sql 

Sql Helper types.

For some dependencies we don’t want to include the rusqlite dependency so we need a way to define the rusqlite::ToSql trait for types defined in upstream crates.

Structs

SqlOutput
A wrapper around rusqlite::types::ToSqlOutput. This allows implementing From<Foo> for SqlOutput for types defined outside this crate.

Traits

AsSql
A helper trait for types we can’t implement rusqlite::ToSql for due to the orphan rule.
ToSqlStatement
A trait to convert a reference of a type to a sql statement for use in rusqlite::Connection prepare.