WireOps

Enum WireOps 

pub enum WireOps {
    Entry(WireEntryOps),
    Record(WireRecordOps),
    Warrant(Box<WarrantOp>),
}
Condensed version of ops for sending across the wire.

Variants



Entry(WireEntryOps)

Response for get entry.



Record(WireRecordOps)

Response for get record.



Warrant(Box<WarrantOp>)

A warrant in place of data in the case that the data is invalid. There is no “wire” version because this is about as compact as it gets.

Implementations

Source

impl WireOps

pub fn render(self) -> DhtOpResult<RenderedOps>

Render the wire ops to DhtOps.

pub fn warrants(&self) -> &[SignedWarrant]

The warrants accompanying this response, proving any Rejected records served. Empty for the standalone-warrant variant.